package com.bonus.material.iot.mapper;

import java.util.List;
import com.bonus.material.iot.domain.IotMachineBind;

/**
 * 设备类型绑定Mapper接口
 * 
 * @author xsheng
 * @date 2024-10-16
 */
public interface IotMachineBindMapper {
    /**
     * 查询设备类型绑定
     * 
     * @param id 设备类型绑定主键
     * @return 设备类型绑定
     */
    public IotMachineBind selectIotMachineBindById(Long id);

    /**
     * 查询设备类型绑定列表
     * 
     * @param iotMachineBind 设备类型绑定
     * @return 设备类型绑定集合
     */
    public List<IotMachineBind> selectIotMachineBindList(IotMachineBind iotMachineBind);

    /**
     * 新增设备类型绑定
     * 
     * @param iotMachineBind 设备类型绑定
     * @return 结果
     */
    public int insertIotMachineBind(IotMachineBind iotMachineBind);

    /**
     * 修改设备类型绑定
     * 
     * @param iotMachineBind 设备类型绑定
     * @return 结果
     */
    public int updateIotMachineBind(IotMachineBind iotMachineBind);

    /**
     * 删除设备类型绑定
     * 
     * @param id 设备类型绑定主键
     * @return 结果
     */
    public int deleteIotMachineBindById(Long id);

    /**
     * 批量删除设备类型绑定
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteIotMachineBindByIds(Long[] ids);
}
