package com.bonus.material.iot.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.iot.domain.IotMachineBind;
import com.bonus.material.iot.service.IIotMachineBindService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 设备类型绑定Controller
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "设备类型绑定接口")
@RestController
@RequestMapping("/iot_machine_bind")
public class IotMachineBindController extends BaseController {
    @Autowired
    private IIotMachineBindService iotMachineBindService;

    /**
     * 查询设备类型绑定列表
     */
    @ApiOperation(value = "查询设备类型绑定列表")
    @RequiresPermissions("iot:bind:list")
    @GetMapping("/list")
    public TableDataInfo list(IotMachineBind iotMachineBind) {
        startPage();
        List<IotMachineBind> list = iotMachineBindService.selectIotMachineBindList(iotMachineBind);
        return getDataTable(list);
    }

    /**
     * 导出设备类型绑定列表
     */
    @ApiOperation(value = "导出设备类型绑定列表")
    @PreventRepeatSubmit
    @RequiresPermissions("iot:bind:export")
    @SysLog(title = "设备类型绑定", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出设备类型绑定")
    @PostMapping("/export")
    public void export(HttpServletResponse response, IotMachineBind iotMachineBind) {
        List<IotMachineBind> list = iotMachineBindService.selectIotMachineBindList(iotMachineBind);
        ExcelUtil<IotMachineBind> util = new ExcelUtil<IotMachineBind>(IotMachineBind.class);
        util.exportExcel(response, list, "设备类型绑定数据");
    }

    /**
     * 获取设备类型绑定详细信息
     */
    @ApiOperation(value = "获取设备类型绑定详细信息")
    @RequiresPermissions("iot:bind:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(iotMachineBindService.selectIotMachineBindById(id));
    }

    /**
     * 新增设备类型绑定
     */
    @ApiOperation(value = "新增设备类型绑定")
    @PreventRepeatSubmit
    @RequiresPermissions("iot:bind:add")
    @SysLog(title = "设备类型绑定", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增设备类型绑定")
    @PostMapping
    public AjaxResult add(@RequestBody IotMachineBind iotMachineBind) {
        try {
            return toAjax(iotMachineBindService.insertIotMachineBind(iotMachineBind));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改设备类型绑定
     */
    @ApiOperation(value = "修改设备类型绑定")
    @PreventRepeatSubmit
    @RequiresPermissions("iot:bind:edit")
    @SysLog(title = "设备类型绑定", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改设备类型绑定")
    @PutMapping
    public AjaxResult edit(@RequestBody IotMachineBind iotMachineBind) {
        try {
            return toAjax(iotMachineBindService.updateIotMachineBind(iotMachineBind));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除设备类型绑定
     */
    @ApiOperation(value = "删除设备类型绑定")
    @PreventRepeatSubmit
    @RequiresPermissions("iot:bind:remove")
    @SysLog(title = "设备类型绑定", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除设备类型绑定")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(iotMachineBindService.deleteIotMachineBindByIds(ids));
    }
}
